%% qtbug.m - a script to demo

clear all;
chdir (fileparts(mfilename("fullpath")));

load QTBUG.mat;
%{
   Variables in the current scope:
   A   BF  BT  P   XX
%}

%% generate (e, sig) points
nR = 10000;                           % half the random points generated
XR1 = 0.1 * rand(4, nR);
XR2 = 0.1 * rand(4, nR);
ZR1 = XR1 - ones(4, 1) * mean(XR1);   % deviations from the mean
ZR2 = XR2 - ones(4, 1) * mean(XR2);   % deviations from the mean
PR1 = P(:, 1) * ones(1, nR) + ZR1;    % random portfolios near P(:, 1)
PR2 = P(:, 2) * ones(1, nR) + ZR2;    % random portfolios near P(:, 2)
AR = A * [PR1, PR2];                  % 2 * nR random price vectors
RR = 100 * (AR([2 : 253], :) ./ AR([1 : 252], :) - 1);  % daily returns
ER = sum(RR);                         % expected returns
SigR = sqrt(252) * std(RR, 1);        % stdevs of return

%% special (e, sig) points
aF154 = A * P(:, 1);
rF154 = 100 * (aF154(2 : 253) ./ aF154(1 : 252) - 1);
eF154 = sum(rF154);
sigF154 = sqrt(252) * std(rF154, 1);
aX = A * P(:, 2);
rX = 100 * (aX(2 : 253) ./ aX(1 : 252) - 1);
eX = sum(rX);
sigX = sqrt(252) * std(rX, 1);
eXX = XX(1);
sigXX = XX(2);

% obtainable/unobtainable patch
EF = [BF(1, :), 14.1 , 13.5];
SigF = [BF(2, :), 2.9, 2.9];

% obtainable patch
ET = [BT(1, :), 14.1 , 13.5];
SigT = [BT(2, :), 2.9, 2.9];

close all;
hold on;

patch(EF, SigF, [0.925, 0.886, 0.843], "edgecolor", "none");
patch(ET, SigT, [0.85, 0.85, 1], "edgecolor", "none");

rectx = [13.5, 14.1, 14.1, 13.5, 13.5];
recty = [2.6, 2.6, 2.9, 2.9, 2.6];
plot( ...
  ER, SigR, ".b", "markersize", 2, ...
  rectx, recty, "-k", ...
  EF, SigF, "-k", ...
  eF154, sigF154, ".r", "markersize", 12, "markeredgecolor", "k", ...
  eX, sigX, ".y", "markersize", 12, "markeredgecolor", "k", ...
  eXX, sigXX, ".k", "markersize", 10 ...
);
axis([13.5, 14.1, 2.6, 2.9], "equal");
text(14.002, 2.758, "F154", "fontsize", 12, "fontweight", "bold");
text(14.009, 2.690, "XX", "fontsize", 12, "fontweight", "bold");
text(13.538, 2.635, "X", "fontsize", 12, "fontweight", "bold");
text(13.79, 2.636, "bogus efficient boundary", "fontsize", 12, ...
  "rotation", 14);
text(13.74, 2.660, "unobtainable (e, sig)", "fontsize", 12, ...
  "rotation", 14);
text(13.70, 2.678, "true efficient boundary", "fontsize", 12, ...
  "rotation", 14);
text(13.56, 2.83, "obtainable (e, sig)", "fontsize", 12, ...
  "rotation", 14);
set(get(gca, "xlabel"), "string", ...
  "annualized mean daily return", "fontsize", 12);
set(get(gca, "ylabel"), "string", ...
  "annualized standard deviation of daily return", "fontsize", 12);
set(gca, "tickdir", "out", ...
  "xtick", [13.5, 13.6, 13.7, 13.8, 13.9, 14.0, 14.1], ...
  "ytick", [2.6, 2.7, 2.8, 2.9]);
set(gca, "title", "New Markowitz: how not to do mean-variance");
set(get(gca, "title"), "fontsize", 12);

hold off;

